@@ -1,6 +1,8 @@
 `design.rcbd` <-
-function (trt, r,number=1,seed=0,kinds="Super-Duper",first=FALSE )
+function (trt, r,serie=2,seed=0,kinds="Super-Duper",first=FALSE )
 {
+number<-10
+if(serie>0) number<-10^serie
 ntr <- length(trt)
 if(seed != 0) set.seed(seed,kinds)
 mtr <- sample(trt, ntr, replace = FALSE)
@@ -12,11 +14,8 @@ mtr <- c(mtr, sample(trt, ntr, replace = FALSE))
 if(!first) mtr[1:ntr]<-trt
 if (!first)
 	mtr[1:ntr] <- trt
-plots <- number + 1:(ntr * r) - 1
+plots <- block*number+(1:ntr)
 book <- data.frame(plots, block = as.factor(block), trt = as.factor(mtr))
 names(book)[3] <- c(paste(deparse(substitute(trt))))
 return(book)
 }
-
-
-
