@@ -3,41 +3,28 @@ function (x, breaks="sturges",counts=NULL,frequency=1, plot=TRUE, nclass=NULL,xl
 {
 if (xlab=="") xlab= deparse(substitute(x))
 if (is.numeric(x) & is.null(counts)) {
-# histogram
+x<-na.omit(x)
+	# histogram
 if (is.null(nclass)) {
 if (length(breaks)==1) {
-x<-na.omit(x)
+
 if(breaks== "sturges") breaks <- sturges.freq(x)$breaks
 }
 }
 else {
-amplitud <- max(x)-min(x)
-n <- length(x)
-z<-rep(0,n)
-y<- as.character(x)
-for (i in 1:n) {
-lc<-nchar(y[i])
-nd<-0
-for (j in 1:lc) {
-a <- substr(y[i],j,j)
-if(a!=".")nd=nd+1
-else break
-}
-z[i]<- lc-nd-1
-}
-d<-max(z)
-if(d<0) d=0
-tic <- round(amplitud/nclass + 0.5 * 10^(-d), d)
-breaks <-seq(min(x), by=tic, length=nclass+1)
+breaks <- sturges.freq(x,k=nclass)$breaks
 }
 
 k<-length(breaks)
 n<- length(x)
 counts <- rep(0,k-1)
 for (i in 1:n) {
-for (j in 1:(k-1)) {
+for (j in 1:(k-2)) {
 if( (x[i] >= breaks[j]) && (x[i] < breaks[j + 1])) counts[j]<-counts[j]+1
 }
+}
+for (i in 1:n) {
+	if( (x[i] >= breaks[k-1]) && (x[i] <= breaks[k])) counts[k-1]<-counts[k-1]+1
 }
     k <- length(counts)
     mids <- rep(0, k)
