@@ -1,5 +1,5 @@
 `scheffe.test` <-
-		function (y, trt, DFerror, MSerror, Fc, alpha=0.05, group=TRUE,main = NULL)
+		function (y, trt, DFerror, MSerror, Fc, alpha=0.05, group=TRUE,main = NULL,console=FALSE)
 {
 	name.y <- paste(deparse(substitute(y)))
 	name.t <- paste(deparse(substitute(trt)))
@@ -14,7 +14,7 @@
 		nipch<- length(ipch)
 		for(i in 1:nipch){
 			if (is.na(ipch[i]))
-				return(cat("Name: ", trt, "\n", names(A)[-1], "\n"))
+				return(if(console)cat("Name: ", trt, "\n", names(A)[-1], "\n"))
 		}
 		name.t<- names(A)[ipch][1]
 		trt <- A[, ipch]
@@ -34,13 +34,14 @@
 	nn <-   tapply.stat(junto[,1],junto[,2],stat="length") # change
 	mi<-tapply.stat(junto[,1],junto[,2],stat="min") # change
 	ma<-tapply.stat(junto[,1],junto[,2],stat="max") # change
-	means<-data.frame(means,std.err=sds[,2]/sqrt(nn[,2]),r=nn[,2],Min.=mi[,2],Max.=ma[,2])
+	means<-data.frame(means,std.err=sqrt(MSerror)/sqrt(nn[,2]),r=nn[,2],Min.=mi[,2],Max.=ma[,2])
 	names(means)[1:2]<-c(name.t,name.y)
 #   row.names(means)<-means[,1]
 	ntr<-nrow(means)
 	Fprob <- qf(1-alpha,ntr-1, DFerror)
 	Tprob <- sqrt(Fprob * (ntr - 1))
 	nr<- 1/mean(1/nn[,2])
+	if(console){
 	cat("\nStudy:", main)
 	cat("\n\nScheffe Test for",name.y,"\n")
 	cat("\nMean Square Error  :",MSerror,"\n\n")
@@ -48,15 +49,16 @@
 	print(data.frame(row.names = means[,1], means[,-1]))
 	cat("\nalpha:",alpha,"; Df Error:",DFerror,"\n")
 	cat("Critical Value of F:", Fprob,"\n")
+	}
 	scheffe <- Tprob*sqrt(2*MSerror/nr)
 	if (length(unique(nn[,2]))!=1) {
-		cat("\nHarmonic Mean of Cell Sizes ", nr )
+		if(console)cat("\nHarmonic Mean of Cell Sizes ", nr )
 	}
 	if (group) {
-		cat("\nMinimum Significant Difference:",scheffe,"\n")
+		if(console){cat("\nMinimum Significant Difference:",scheffe,"\n")
 		cat("\nMeans with the same letter are not significantly different.")
-		cat("\n\nGroups, Treatments and means\n")
-		groups <- order.group(means[,1], means[,2], means[,4], MSerror, Tprob,means[,3], parameter=1)
+		cat("\n\nGroups, Treatments and means\n")}
+		groups <- order.group(means[,1], means[,2], means[,4], MSerror, Tprob,means[,3], parameter=1,console=console)
 		comparison=NULL
 		groups <- data.frame(groups[,1:3])
 	}
@@ -91,8 +93,8 @@
 		tr.j <- means[comb[2, ],1]
 		comparison<-data.frame("Difference" = dif, pvalue=pvalue,sig,LCL,UCL)
 		rownames(comparison)<-paste(tr.i,tr.j,sep=" - ")
-		cat("\nComparison between treatments means\n\n")
-		print(comparison)
+		if(console){cat("\nComparison between treatments means\n\n")
+		print(comparison)}
 		groups=NULL
 #		output<-data.frame(trt= means[,1],means= means[,2],M="",N=means[,4],std.err=means[,3])
 	}
